@@ -17,6 +17,7 @@ def lisaa_lomakesarja(
   avain_b=None,
   tunnus=None,
   epasuora=False,
+  valita_parametrit=None,
   **kwargs
 ):
   '''
@@ -69,7 +70,7 @@ def lisaa_lomakesarja(
   if not hasattr(lomakesarja, 'palikka'):
     lomakesarja.palikka = 'pumaska/lomakesarja_lomakekenttana.html'
   if not hasattr(lomakesarja, 'riviluokka'):
-    lomakesarja.riviluokka = 'clearfix'
+    lomakesarja.riviluokka = 'panel panel-default clearfix'
   if not hasattr(lomakesarja, 'lisaa_painike'):
     lomakesarja.lisaa_painike = _('Lisää %(malli)s') % {
       'malli': LomakeB.Meta.model._meta.verbose_name
@@ -89,6 +90,11 @@ def lisaa_lomakesarja(
 
     def __init__(self, *args, prefix=None, **kwargs):
       lomakesarja_kwargs = kwargs.pop(f'{tunnus}_kwargs', {})
+      for param in (valita_parametrit or ()):
+        try:
+          lomakesarja_kwargs[param] = kwargs[param]
+        except KeyError:
+          pass
       super().__init__(*args, prefix=prefix, **kwargs)
       initial = {
         avain.replace(tunnus + '-', '', 1): arvo
